from enum import Enum

class ReactionType(int, Enum):
    RED_HEART = 1
    THUMBS_UP, LIKE = 2, 2
    THUMBS_DOWN, UN_LIKE = 3, 3
    FIRE = 4
    SMILING_FACE_WITH_HEARTS = 5
    CLAPPING_HANDS = 6
    IRAN = 7
    BEAMING_FACE = 8
    THINKING_FACE = 9
    EXPLODING_HEAD = 10
    SCREAMING_FACE = 11
    FACE_WITH_SYMBOLS_ON_MOUTH = 12
    CRYING_FACE = 13
    CELEBRATION = 14
    PARTY_POPPER = 15
    STAR_STRUCK = 16
    FACE_VOMITING = 17
    PILE_OF_POO = 18
    FOLDED_HANDS = 19
    OKAY = 20
    DOVE_OF_PEACE = 21
    CLOWN_FACE = 22
    YAWNING_FACE = 23
    WOOZY_FACE = 24
    SMILING_FACE_WITH_HEART_EYES = 25
    WHALE = 26
    HEART_ON_FIRE = 27
    NEW_MOON_FACE = 28
    HOT_DOG = 29
    HUNDRED_POINTS = 30
    ROLLING_ON_THE_FLOOR_LAUGHING = 31
    HIGH_VOLTAGE = 32
    BANANA = 33
    TROPHY = 34
    BROKEN_HEART = 35
    FACE_WITH_RAISED_EYEBROW = 36
    NEUTRAL_FACE = 37
    STRAWBERRY = 38
    KISS_MARK = 39
    SMILING_FACE_WITH_HORNS = 40
    SLEEPING = 41
    LOUDLY_CRYING_FACE = 42
    NERD_FACE = 43
    GHOST = 44
    MAN_TECHNOLOGIST = 45
    EYES = 46
    JACK_O_LANTERN = 47
    SEE_NO_EVIL_MONKEY = 48
    SMILING_FACE_WITH_HALO = 49
    FEARFUL_FACE = 50
    HANDSHAKE = 51
    WRITING_HANDS = 52
    HUGGING_FACE = 53
    SANTA_CLAUS = 54
    CHRISTMAS_TREE = 55
    SNOWMAN = 56
    NAIL_POLISH = 57
    ZANY_FACE = 58
    MOAI = 59
    COOL_BUTTON = 60
    HEART_WITH_ARROW = 61
    HEAR_NO_EVIL_MONKEY = 62
    UNICORN = 63
    FACE_BLOWING_A_KISS = 64
    PILL = 65
    SPEAK_NO_EVIL_MONKEY = 66
    SMILING_FACE_WITH_SUNGLASSES = 67
    ALIEN_MONSTER = 68
    SHRUGGING_MAN = 69
    SHRUGGING_PERSON = 70
    SHRUGGING_WOMAN = 71
    RAGE = 72