class ChatAction:
    """Chat action enumeration used in :obj:`~pyrogram.types.ChatEvent`."""

    TYPING = 'Typing'
    "Typing text message"

    UPLOADING = 'Uploading'
    "Uploading photo"

    RECORD_AUDIO = 'Recording'
    "Recording audio"